@@ -184,7 +184,7 @@ def pack_lengths(itr_of_arrays):
                           [25, 26, 27, 28]])
         np.array([3, 20, 21, 22, 2, 23, 24, 4, 25, 26, 27, 28])
 
-    .. sealso:
+    .. seealso:
 
         unpack_lengths for the reverse.
     """
@@ -292,7 +292,7 @@ class PolyData(object):
     The points aren't visible themselves - to create some kind of points plot
     use :meth`scatter`.
 
-    Lines and polyons can be interchanged to switch from solid surface to
+    Lines and polygons can be interchanged to switch from solid surface to
     wire-frame.
 
 
@@ -524,9 +524,7 @@ def test(*spam):
 
     self = PolyData()
 
-
-    from stl.mesh import Mesh
-    vectors = Mesh.from_file(vpl.data.get_rabbit_stl()).vectors
+    vectors = vpl.mesh_plot(vpl.data.get_rabbit_stl(), fig=None).vectors
 
 
     points = vectors.reshape((-1, 3))
